==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Ladrès sit ou', # MODIF
	'form_pet_aucune_signature' => 'Okenn siyati ka koresponn kod-la...', # MODIF
	'form_pet_confirmation' => 'Mèsi konfime siyati ou :',
	'form_pet_deja_signe' => 'W te deja sinye tèks-la.',
	'form_pet_envoi_mail_confirmation' => 'Yon limèl pou konfine te fin voye a w. Fòk w vizite ladrès wèb te done nan limèl pou w konfime siyati ou.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjou,

W la domman mèt siyati nan petisyon-nan :
@titre@.

W te done tout ranséynman  swivan :
    Kouman rele: @nom_email@
    sit ou: @nom_site@ - @url_site@

...

Pou konfime siyati-a, fòk sèlman w abòd ladrès anba (sinon, sitwèb-la ke pa enskri siyati ou) :
    @url@

Mèsi  w soutni petisyon-nan
', # MODIF
	'form_pet_nom_site2' => 'Kouman sitwèb ou rele', # MODIF
	'form_pet_probleme_technique' => 'Pwoblèm teknik, siyati se pa posib kounye-a. Tann pwoblèm-la ke aranje pou rete sispann a yo.',
	'form_pet_signature_validee' => 'Siyati ou se konfime. Mèsi !',
	'form_pet_site_deja_enregistre' => 'Sit-la se deja enskri',
	'form_pet_url_invalide' => 'URL w te done se pa bon.',
	'form_pet_votre_email' => 'Ladrès limèl ou',
	'form_pet_votre_nom' => 'Kouman w rele', # MODIF
	'form_pet_votre_site' => 'Si w ap gen sitwèb, se posib enskri ali isit-enba-mèm',

	// I
	'info_adresse_email' => 'LADRES LIMEL :',
	'info_site_web' => 'SIT WEB :',

	// L
	'lien_reponse_article' => 'Réponn atik-la'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Mèt yon pétisyon',
	'bouton_radio_pas_petition' => 'Okenn petisyon',
	'bouton_radio_petition_activee' => 'Petisyon ka mache',
	'bouton_radio_supprimer_petition' => 'Kraez petisyon nan',

	// F
	'form_pet_adresse_site' => 'Ladrès sit ou', # MODIF
	'form_pet_aucune_signature' => 'Okenn siyati ka koresponn kod-la...', # MODIF
	'form_pet_confirmation' => 'Mèsi konfime siyati ou :',
	'form_pet_deja_signe' => 'W te deja sinye tèks-la.',
	'form_pet_envoi_mail_confirmation' => 'Yon limèl pou konfine te fin voye a w. Fòk w vizite ladrès wèb te done nan limèl pou w konfime siyati ou.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjou,

W la domman mèt siyati nan petisyon-nan :
@titre@.

W te done tout ranséynman  swivan :
    Kouman rele: @nom_email@
    sit ou: @nom_site@ - @url_site@

...

Pou konfime siyati-a, fòk sèlman w abòd ladrès anba (sinon, sitwèb-la ke pa enskri siyati ou) :
    @url@

Mèsi  w soutni petisyon-nan
', # MODIF
	'form_pet_nom_site2' => 'Kouman sitwèb ou rele', # MODIF
	'form_pet_probleme_technique' => 'Pwoblèm teknik, siyati se pa posib kounye-a. Tann pwoblèm-la ke aranje pou rete sispann a yo.',
	'form_pet_signature_validee' => 'Siyati ou se konfime. Mèsi !',
	'form_pet_site_deja_enregistre' => 'Sit-la se deja enskri',
	'form_pet_url_invalide' => 'URL w te done se pa bon.',
	'form_pet_votre_email' => 'Ladrès limèl ou',
	'form_pet_votre_nom' => 'Kouman w rele', # MODIF
	'form_pet_votre_site' => 'Si w ap gen sitwèb, se posib enskri ali isit-enba-mèm',

	// I
	'info_adresse_email' => 'LADRES LIMEL :',
	'info_site_web' => 'SIT WEB :',

	// L
	'lien_reponse_article' => 'Réponn atik-la'
);

?>
